summary refs log tree commit diff
path: root/time/tzfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'time/tzfile.h')
-rw-r--r--time/tzfile.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/time/tzfile.h b/time/tzfile.h
index a26fbbeefc..90441cbbc3 100644
--- a/time/tzfile.h
+++ b/time/tzfile.h
@@ -21,7 +21,7 @@
 
 #ifndef lint
 #ifndef NOID
-static char	tzfilehid[] = "@(#)tzfile.h	7.9";
+static char	tzfilehid[] = "@(#)tzfile.h	7.13";
 #endif /* !defined NOID */
 #endif /* !defined lint */
 
@@ -45,8 +45,11 @@ static char	tzfilehid[] = "@(#)tzfile.h	7.9";
 ** Each file begins with. . .
 */
 
+#define	TZ_MAGIC	"TZif"
+
 struct tzhead {
-	char	tzh_reserved[20];	/* reserved for future use */
+ 	char	tzh_magic[4];		/* TZ_MAGIC */
+	char	tzh_reserved[16];	/* reserved for future use */
 	char	tzh_ttisgmtcnt[4];	/* coded number of trans. time flags */
 	char	tzh_ttisstdcnt[4];	/* coded number of trans. time flags */
 	char	tzh_leapcnt[4];		/* coded number of leap seconds */